@@ -13,7 +13,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 has timeout => (
@@ -116,7 +116,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -257,12 +257,8 @@ If you see warnings like this:
  Class::MOP::load_class("Crypt::Random::Source::Weak::devurandom") called at .../Crypt/Random/Source/Factory.pm line 137
  ...
 
-The problem is in the optional L<Crypt::Random::Source> module, and has
-been reported here:
-
-L<https://rt.cpan.org/Ticket/Display.html?id=93163&results=822cf3902026ad4a64ae94b0175207d6>
-
-You can use the patch provided there to silence the warnings.
+The problem is in the optional L<Crypt::Random::Source> module, and 
+reportedly been fixed in its version 0.08.
 
 =head1 SEE ALSO
 
@@ -314,7 +310,7 @@ L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 contributors:
 
