@@ -13,7 +13,7 @@ use AnyEvent::WebSocket::Message;
 use Carp qw( croak carp );
 
 # ABSTRACT: WebSocket connection for AnyEvent
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 has handle => (
@@ -227,7 +227,7 @@ AnyEvent::WebSocket::Connection - WebSocket connection for AnyEvent
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -334,10 +334,11 @@ L<Protocol::WebSocket>.
 
 =head1 DEPRECATED METHODS
 
-The methods in this section are deprecated and may be removed from a
-future version of this class.  They should not be used for new code,
-and are only remain documented here to aid in understanding legacy
-code that use them.
+The methods in this section are deprecated and will be removed on or
+after 11 October 2015, at which point they will have been deprecated
+for two years.   They should not be used for new code, and are only
+remain documented here to aid in understanding legacy code that use
+them.
 
 =head2 $connection-E<gt>on_each_message($cb)
 
@@ -387,7 +388,7 @@ L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 contributors:
 
